package com.ruoyi.business.mapper;

import java.util.List;
import com.ruoyi.business.domain.HwMonitorUnitType;
import com.ruoyi.business.domain.VO.DeviceModeVo;

/**
 * 监控单元类型Mapper接口
 *
 * @author YINQ
 * @date 2023-08-31
 */
public interface HwMonitorUnitTypeMapper
{
    /**
     * 查询监控单元类型
     *
     * @param monitorUnitTypeId 监控单元类型主键
     * @return 监控单元类型
     */
    public HwMonitorUnitType selectHwMonitorUnitTypeByMonitorUnitTypeId(Long monitorUnitTypeId);

    /**
     * 查询监控单元类型列表
     *
     * @param hwMonitorUnitType 监控单元类型
     * @return 监控单元类型集合
     */
    public List<HwMonitorUnitType> selectHwMonitorUnitTypeList(HwMonitorUnitType hwMonitorUnitType);




    /**
     * 新增监控单元类型
     *
     * @param hwMonitorUnitType 监控单元类型
     * @return 结果
     */
    public int insertHwMonitorUnitType(HwMonitorUnitType hwMonitorUnitType);

    /**
     * 修改监控单元类型
     *
     * @param hwMonitorUnitType 监控单元类型
     * @return 结果
     */
    public int updateHwMonitorUnitType(HwMonitorUnitType hwMonitorUnitType);

    /**
     * 删除监控单元类型
     *
     * @param monitorUnitTypeId 监控单元类型主键
     * @return 结果
     */
    public int deleteHwMonitorUnitTypeByMonitorUnitTypeId(Long monitorUnitTypeId);

    /**
     * 批量删除监控单元类型
     *
     * @param monitorUnitTypeIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteHwMonitorUnitTypeByMonitorUnitTypeIds(Long[] monitorUnitTypeIds);
}
